from .main import Tear
from .router.inner import Router
from .router.methods import chat, cos, embed, route, training
from chat import chat
from cos import cos
from embed import embed
from route import route
from training import trainWithFile
